@@ -1,6 +1,6 @@
 package Pb::Command::Context;
 
-our $VERSION = '0.01_04'; # TRIAL VERSION
+our $VERSION = '0.01'; # VERSION
 
 use Moo;
 use 5.14.0;
@@ -93,8 +93,7 @@ sub _prep_filename
 sub _extrapolate_run_mode
 {
 	my ($self) = @_;
-	return 'NOACTION'  if $self->_opts->{pretend};
-	return 'ASKACTION' if $self->_opts->{interactive};
+	return 'NOACTION' if $self->_opts->{pretend};
 	return 'ACTION';
 }
 
@@ -398,7 +397,7 @@ Pb::Command::Context - context object for a Pb command
 
 =head1 VERSION
 
-This document describes version 0.01_04 of Pb::Command::Context.
+This document describes version 0.01 of Pb::Command::Context.
 
 =head1 DESCRIPTION
 
@@ -407,27 +406,6 @@ may be useful for calling on the C<$FLOW> object.
 
 =head1 ATTRIBUTES
 
-=head2 runmode
-
-Whether commands are printed or not then executed or not.
-
-=head2 statfile
-
-Status file for the command (if any).
-
-=head2 proc_pidfile
-
-L<Proc::Pidfile> object for the command (if any).
-
-=head2 toplevel_command
-
-L<CLI::Osprey> object for the (ultimate) parent of the current command.  (If the command has no
-parent, C<toplevel_command> is just the current command.)
-
-=head2 update_statfile
-
-Whether or not to update the L</statfile> for the current error.
-
 =head2 error
 
 Last recorded error.
@@ -494,7 +472,7 @@ Get a logfile ready for outputting to.
 
 =head2 prep_pidfile
 
-Build a L<Proc::Pidfile> object and handle any "already running" issues.
+Build a Proc::Pidfile object and handle any "already running" issues.
 
 =head1 AUTHOR
 
