@@ -4,15 +4,13 @@ use 5.14.0;
 use autodie ':all';
 
 use Exporter 'import';
-our @EXPORT = qw< pb_basecmd pb_run check_output check_error _slurp %ERRNO >;
+our @EXPORT = qw< pb_basecmd pb_run check_output check_error _slurp >;
 
 
 use Test::Most;
 
-use Errno				();
 use File::Temp			qw< tempdir >;
 use File::Path			qw< make_path >;
-use File::Spec;
 use File::Basename;
 
 
@@ -20,23 +18,6 @@ my $TMPDIR = tempdir( TMPDIR => 1, CLEANUP => 1 );
 my $BASE;
 
 
-# this is how PerlX::bash does it
-{
-    my $devnull = File::Spec->devnull;
-    my $msg = 'successful';
-    `bash -c "echo $msg" 2>$devnull` eq "$msg\n" or plan skip_all => "no bash available!";
-}
-
-
-# This helps us avoid errors in non-English locales.  See
-# https://github.com/barefootcoder/leadpipe/issues/2 for the discussion which led to this.  Thx to
-# Slaven Rezić (a.k.a. SREZIC, a.k.a. eserte) for the suggestion.
-our %ERRNO =
-(
-	ENOENT		=> do { $! = Errno::ENOENT;    "$!" },	# No such file or directory
-);
-
-
 # helpers
 
 # poor man's slurp, compressed, mostly courtesy of:
@@ -107,7 +88,7 @@ sub check_error
 {
 	my $testname = pop;
 	my $trap = shift;
-	my $exit = $_[0] =~ /^\d+$/ ? shift : $_[0] eq '?' ? (shift, qr/[12]\d*/) : 1;
+	my $exit = $_[0] =~ /^\d+$/ ? shift : 1;
 	my @lines = @_;
 	local $Test::Builder::Level = $Test::Builder::Level + 1;
 
